@@ -5,13 +5,12 @@ from django.db.utils import OperationalError, ProgrammingError
 
 
 class ExtraSettingsConfig(AppConfig):
-
     name = "extra_settings"
     verbose_name = settings.EXTRA_SETTINGS_VERBOSE_NAME
     default_auto_field = "django.db.models.AutoField"
 
     def ready(self):
-        from extra_settings import signals
+        from extra_settings import signals  # noqa: F401
         from extra_settings.models import Setting
 
         try:
