@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from django.conf import settings
 from django.core.cache import cache, caches
 
@@ -10,7 +8,7 @@ def _get_cache():
 
 
 def _get_cache_key(key):
-    return "extra_settings_{}".format(key)
+    return f"extra_settings_{key}"
 
 
 def del_cached_setting(key):
