@@ -1,12 +1,7 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import absolute_import
-
 from django import template
 
 from extra_settings.models import Setting
 
-
 register = template.Library()
 
 
