@@ -1,12 +1,8 @@
-from extra_settings.cache import (
-    del_cached_setting,
-    get_cached_setting,
-    set_cached_setting,
-)
+from extra_settings.cache import del_cached_setting, set_cached_setting
 from extra_settings.models import Setting
 
 
-class override_settings(object):
+class override_settings:
     """
     This class describes the override_settings decorator / context manager.
     """
